/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#include "muscle.h"
#include <stdio.h>

static char szOnExceptionMessage[] =
	{
	"\nFatal error, exception caught.\n"
	};

void OnException()
	{
	fprintf(stderr, "%s", szOnExceptionMessage);
	//Log(szOnExceptionMessage);
        //Log("Finished %s\n", GetTimeAsStr());
	exit(EXIT_Except);
	}
